==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/AppconfigmasterCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Appconfigmaster;
import microsoft.dynamics.crm.entity.request.AppconfiginstanceRequest;
import microsoft.dynamics.crm.entity.request.AppconfigmasterRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class AppconfigmasterCollectionRequest extends CollectionPageEntityRequest<Appconfigmaster, AppconfigmasterRequest>{

    protected ContextPath contextPath;

    public AppconfigmasterCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Appconfigmaster.class, cp -> new AppconfigmasterRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public AppconfiginstanceCollectionRequest appconfigmaster_appconfiginstance() {
        return new AppconfiginstanceCollectionRequest(contextPath.addSegment("appconfigmaster_appconfiginstance"), Optional.empty());
    }

    public AppconfiginstanceRequest appconfigmaster_appconfiginstance(String appconfiginstanceid) {
        return new AppconfiginstanceRequest(contextPath.addSegment("appconfigmaster_appconfiginstance").addKeys(new NameValue(appconfiginstanceid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/AppconfigmasterCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Appconfigmaster;
import microsoft.dynamics.crm.entity.request.AppconfiginstanceRequest;
import microsoft.dynamics.crm.entity.request.AppconfigmasterRequest;

public class AppconfigmasterCollectionRequest extends CollectionPageEntityRequest<Appconfigmaster, AppconfigmasterRequest>{

    protected ContextPath contextPath;

    public AppconfigmasterCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Appconfigmaster.class, cp -> new AppconfigmasterRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public AppconfiginstanceCollectionRequest appconfigmaster_appconfiginstance() {
        return new AppconfiginstanceCollectionRequest(contextPath.addSegment("appconfigmaster_appconfiginstance"), Optional.empty());
    }

    public AppconfiginstanceRequest appconfigmaster_appconfiginstance(String appconfiginstanceid) {
        return new AppconfiginstanceRequest(contextPath.addSegment("appconfigmaster_appconfiginstance").addKeys(new NameValue(appconfiginstanceid.toString())), Optional.empty());
    }

}
